abacusai.messaging_connector_response — AbacusAI documentation

# `abacusai.messaging_connector_response`

## Module Contents

### Classes

`MessagingConnectorResponse` | The response to view label data for Teams

class abacusai.messaging_connector_response.MessagingConnectorResponse(client, welcomeMessage=None, defaultMessage=None, disclaimer=None, messagingBotName=None, useDefaultLabel=None, initAckReq=None, defaultLabels=None, enabledExternalLinks=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The response to view label data for Teams

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - welcomeMessage (str) – on the first installation of the app the user will get this message

    - defaultMessage (str) – when user triggers hi, hello, help they will get this message

    - disclaimer (str) – given along with every bot response

    - messagingBotName (str) – the name you want to see at various places instead of Abacus.AI

    - useDefaultLabel (bool) – to use the default Abacus.AI label in case it is set to true

    - initAckReq (bool) – Set to true if the initial Acknowledgment for the query is required by the user

    - defaultLabels (dict) – Dictionary of default labels, if the user-specified labels aren’t set

    - enabledExternalLinks (list) – list of external application which have external links applicable

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict